==> quidproquo-actionprocessor-awslambda-0.0.212.tgz: package/lib/esm/logic/cognito/cognitoAttributeMap.js <==
export const cognitoAttributeMap = {
    email: 'email',
    emailVerified: 'email_verified',
    userId: 'sub',
    address: 'address',
    birthDate: 'birthdate',
    familyName: 'family_name',
    gender: 'gender',
    givenName: 'given_name',
    locale: 'locale',
    middleName: 'middle_name',
    name: 'name',
    nickname: 'nickname',
    phoneNumber: 'phone_number',
    picture: 'picture',
    preferredUsername: 'preferred_username',
    profile: 'profile',
    website: 'website',
    zoneInfo: 'zoneinfo',
};
// Flip the cognitoAttributeMap for reverse mapping
const reversedCognitoAttributeMap = Object.entries(cognitoAttributeMap).reduce((acc, [key, value]) => ({ ...acc, [value]: key }), {});
export const getCognitoUserAttributesFromQpqUserAttributes = (userAttributes) => {
    return Object.keys(userAttributes)
        .map((key) => ({
        Name: cognitoAttributeMap[key],
        Value: `${userAttributes[key]}`,
    }))
        .filter((attribute) => !!attribute.Name && !!attribute.Value);
};
export const getQpqAttributesFromCognitoUserAttributes = (cognitoUserAttributes) => {
    // Map cognitoUserAttributes to your UserAttributes format
    const userAttributes = cognitoUserAttributes.reduce((acc, { Name, Value }) => {
        const userAttributeKey = reversedCognitoAttributeMap[Name];
        if (!userAttributeKey) {
            return acc; // If there's no matching key in your mapping, just continue with the current accumulation
        }
        if (userAttributeKey === 'emailVerified') {
            // Assume the value of 'email_verified' is a string of 'true' or 'false'
            return { ...acc, [userAttributeKey]: Value === 'true' };
        }
        return { ...acc, [userAttributeKey]: Value };
    }, {});
    return userAttributes;
};

==> quidproquo-actionprocessor-awslambda-0.0.224.tgz: package/lib/esm/logic/cognito/cognitoAttributeMap.js <==
export const cognitoAttributeMap = {
    email: 'email',
    emailVerified: 'email_verified',
    userId: 'sub',
    address: 'address',
    birthDate: 'birthdate',
    familyName: 'family_name',
    gender: 'gender',
    givenName: 'given_name',
    locale: 'locale',
    middleName: 'middle_name',
    name: 'name',
    nickname: 'nickname',
    phoneNumber: 'phone_number',
    picture: 'picture',
    preferredUsername: 'preferred_username',
    profile: 'profile',
    website: 'website',
    zoneInfo: 'zoneinfo',
};
// Flip the cognitoAttributeMap for reverse mapping
const reversedCognitoAttributeMap = Object.entries(cognitoAttributeMap).reduce((acc, [key, value]) => ({ ...acc, [value]: key }), {});
export const getCognitoUserAttributesFromQpqUserAttributes = (userAttributes) => {
    return Object.keys(userAttributes)
        .map((key) => ({
        Name: cognitoAttributeMap[key],
        Value: `${userAttributes[key]}`,
    }))
        .filter((attribute) => !!attribute.Name && !!attribute.Value);
};
const getQpqAttributeObjectFromCognitoKeyValue = (key, value) => {
    const userAttributeKey = reversedCognitoAttributeMap[key];
    if (!userAttributeKey) {
        return {}; // If there's no matching key in your mapping, just return nothing
    }
    if (userAttributeKey === 'emailVerified') {
        // Assume the value of 'email_verified' is a string of 'true' or 'false'
        return { [userAttributeKey]: value === 'true' };
    }
    return { [userAttributeKey]: value };
};
export const getQpqAttributesFromCognitoUserAttributes = (cognitoUserAttributes) => {
    // Map cognitoUserAttributes to your UserAttributes format
    const userAttributes = cognitoUserAttributes.reduce((acc, { Name, Value }) => {
        return { ...acc, ...getQpqAttributeObjectFromCognitoKeyValue(Name, Value) };
    }, {});
    return userAttributes;
};
export const getQpqAttributesFromCognitoStringMap = (cognitoUserAttributes) => {
    const userAttributes = Object.keys(cognitoUserAttributes).reduce((acc, key) => ({
        ...acc,
        ...getQpqAttributeObjectFromCognitoKeyValue(key, cognitoUserAttributes[key]),
    }), {});
    return userAttributes;
};
